import os
import re
import pandas as pd

from src.analysis.utils_analysis import selected_col, fac_h_perso, fac_info, fac_media
from src.data_fusion import (
    utils,
    compute_criterion,
    ptsd_criterion,
    data_loading,
    utils_socio,
)

#  dict transformation

dict_code_insee = {
    "ETUDIANTS": 1,
    "CADRES ET PROFESSIONS INTELLECTUELLES SUPERIEURES": 7,
    "PROFESSIONS INTERMÉDIAIRES": 6,
    "EMPLOYÉS": 2,
    "CHÔMEURS": 0,
    "OUVRIERS": 3,
    "RETRAITÉS": 4,
    "NR": -1,
    "ARTISANS, COMMERÇANTS ET CHEFS D'ENTREPRISES": 5,
}

dict_code_diplome = {
    "Bac+2": 2,
    "Bac+5": 5,
    "Bac ou moins": 0,
    "Bac+3": 3,
    "Bac+1": 1,
    "Bac+4": 4,
    "Bac+8": 8,
    "AUTRE": -1,
    "Bac+9": 9,
    "Bac+6": 6,
    "Bac+7": 7,
}


dict_h_13_14 = {
    "ENVIRON 3 HEURES": "3",
    "EN PERMANENCE: MÉDIA INTERNET": "24",
    "NON-STOP": "24",
    "DE MANIÈRE PONCTUELLE, PAR BRIBES": "1",
    "TROP": "15",
    "PLUSIEURS": "4",
    "EN CONTINU (POUR CAUSE D'INSOMNIE SUITE AUX ATTENTATS)": "24",
    "30 MINUTES": "0.5",
    "PRESQUE TOUTE LA NUIT": "12",
    "ENORMÉMENT": "10",
    "PLUSIEURS HEURES SUR PLUSIEURS JOURS": "5",
    "10MN": "0.5",
    "1 MINUTE": "0.1",
    "1/2 MINUTES": "0.1",
    "BEAUCOUP": "5",
    "TOUTE LA NUIT DU 13 AU 14 PUIS JUSQU'À 17H30-18H ECOLE MILITAIRE": "24",
    "TOUJOURS": "24",
    "LE MOINS POSSIBLE": "0.5",
    "MOINS D'UNE HEURE": "0.5",
    "[PAGE MANQUANTE]": "NR",
    "JE NE SAIS PAS": "NR",
    "?": "NR",
}

dict_pers_13_14 = {
    "CEUX QUI ONT APPELÉ POUR MON FILS": "5",
    "PLUSIEURS FOIS": "5",
    "NON-STOP": "100",
    "DE MANIÈRE INDIVIDUELLE UNE DIZAINE DE FOIS. MAIS J'AI AUSSI DIRIGÉ UNE RÉUNION AVEC UNE TRENTAINE DE PARTICIPANTS": "10",
    "? (UN TRÈS GRAND NOMBRE DE FOIS)": "10",
    "TRÈS NOMBREUSES FOIS (JE ME SUIS RENDUE AU RASSEMBLEMENT)": "10",
    "?": "NR",
    "EN CONTINU DURANT LA NUIT": "100",
    "?, ÉCHANGES AVEC MON CONJOINT, NON MESURABLE": "NR",
    "? PLUSIEURS FOIS": "5",
    "MOULTE": "10",
    "JE N'AI FAIT QUE CA, PENDANT LA JOURNEE ENTIERE": "50",
    "MULTIPLE": "5",
    "DE FACON CONTINUE CAR J'ETAIS UN ACTEUR DE LA PRISE EN CHARGE DES VICTIMES": "100",
    "PLUS D'UNE CENTAINE DE FOIS": "100",
    "J'AVOUE NE PAS M'EN SOUVENIR EXACTEMENT MAIS CE QUI EST SUR NOUS EN PARLIONS TRES SOUVENT.": "10",
    "24H/24H BEAUCOUP": "100",
    "UNE DIZAINE DE FOIS": "10",
    "PLUSIEURS": "5",
    "TRES NOMBREUSES FOIS (EN 24 H)": "10",
    "BEAUCOUP. ON NE PARLAIT QUE DE CET ÉVÉNEMENT, TOUT ÉTAIT AXÉ EN TERME DE COMMUNICATION.": "50",
    "EN CONTINU": "100",
    "EN PERMANENCE SAUF DURANT MON SOMMEIL": "100",
    "JE NE SAIS PAS MAIS BEAUCOUP BEAUCOUP": "20",
    "TROP": "100",
    "AUCUN SOUVENIR": "NR",
    "DES CENTAINES DE FOIS, PAR MESSAGES INTERPOSÉS": "100",
    "TOUT LE WEEK-END": "100",
    "TOUS LES JOURS": "100",
    "JE NE SAIS PAS": "NR",
    "TOUTE LA PERIODE": "100",
    "INCALCULABLE. J'AI PASSE MON TEMPS AVEC DIFFERENTS AMIS/FAMILLES POUR PRENDRE DES NOUVELLES OU EN DONNER": "50",
    "PAS POSSIBLE DE REPONDRE : BEAUCOUP": "10",
    "BEAUCOUP": "10",
    "INNOMBRABLES": "50",
    "UN NOMBRE INCALCULABLE, PLUSIEURS CENTAINES AU MINIMUM DU FAIT DE MA PROFESSION DE JOURNALISTE": "200",
    "NSP": "NR",
    "EN PERMANENCE": "100",
    "TRÈS NOMBREUSES FOIS": "50",
    "[ILLISIBLE]": "NR",
    "TOUT LE TEMPS": "100",
    "DE TRÈS NOMBREUSES FOIS": "10",
    "BEAUCOUP AVEC LES SECOURISTES": "50",
    "NOMBREUSES FOIS": "5",
    "DES CENTAINES DE FOIS": "100",
    "INCALCULABLE AU MOINS AVEC CENT PERSONNES DIFFÉRENTES": "100",
    "IMPOSSIBLE À COMPTER": "50",
    "INNOMBRABLE": "50",
    "PLUS D'UNE CENTAINE": "100",
    "BEAUCOUP, TOUTE LA SOIRÉE APRÈS 22H": "20",
    "IMPOSSIBLE À QUANTIFIER": "50",
    "PLUSIEURS FOIS, NSP": "5",
    "UN TRÈS GRAND NOMBRE DE FOIS À TITRE PROFESSIONNEL": "100",
    "CEUX QUI ONT APPELÉ POUR MON FILS": "5",
    "TOUT LE TEMPS !": "100",
    "ENORMÉMENT": "50",
    "EN PERMANENCE AVEC LES COLLÈGUES DE LA CROIX-ROUGE ET LES AUTORITÉS SUR PLACE": "100",
    "BEAUCOUP TROP DE FOIS POUR QUANTIFIER": "50",
    "EN CONTINU !": "100",
    "IMPOSSIBLE À QUANTIFIÉ": "50",
    "1 (EN CONTINU AVEC MA FEMME)": "1",
    "MULITPLE": "5",
    "TOUT LE TEMPS AVEC MES COLLÈGUES": "100",
    "TRÈS SOUVENT PROFESSIONNELLEMENT": "50",
    "AVEC LES COLLÈGUES": "20",
    "INCALCULABLE": "50",
    "SANS ARRÊT": "100",
    "DES DIZAINES ET DES DIZAINES DE FOIS": "20",
    "JE NE SAIS PLUS MAIS DE NOMBREUSES FOIS": "10",
    "PAS QUANTIFIABLE, TOUTE LA NUIT": "50",
    "ÉNORMÉMENT": "20",
    "EN CONTINU DU 13 AU 14 JUSQU\x92À MIDI, PUIS 2 FOIS L'APRES MIDI ET 2 FOIS LE SOIR.": "100",
    "TRES SOUVENT, QUASIMENT PLUSIEURS FOIS PAR JOUR": "20",
    "BEAUCOUP. TOUT LE TEMPS PENDANT LES JOURS QUI ONT SUIVI.": "50",
    "DIZAINE": "15",
    "BEAUCOUP, J'AI U DES APPELS TOUTE LA NUIT": "20",
    "TOUT LE TEMPS DEPUIS 5H30 DU MAT, L'HEURE OU JE SUIS RENTREE CHEZ MOI, ET 22H DU SOIR QUAND ENFIN J'AI REUSSI A DORMIR.": "100",
    "XXX": "NR",
    "TOUT LE TEMPS PENDANT LE WEEK-END SUIVANT LES ATTENTATS": "100",
    "UNE VINGTAINE, EN CONSTANTE CONVERSATION TOUTE LA NUIT": "20",
    "TELLEMENT DE FOIS QUE JE NE SAIS PAS": "42",
    "INFINIE": "150",
    "ÉNORMÉMENT DE FOIS": "30",
    "TOUTE LA NUIT": "100",
    "BEAUCOUP DE FOIS, QUASIMENT À CHAQUE MINUTE": "100",
    "DE MULTIPLES FOIS (PAR FONCTION)": "25",
    "DES DIZAINES": "15",
    "DES DIZAINES DE FOIS": "15",
    "TRÈS SOUVENT": "20",
    "BEAUCOUP DE FOIS!": "25",
    "DES MILLIERS DE FOIS": "1000",
    "BEAUCOUP, J'AI U DES APPELS TOUTE LA NUIT.": "50",
}


dict_h_mois = {
    "Plus d’une fois ce mois-ci": "Plus d’une fois ce mois-ci",
    "Plus d’une fois par semaine": "Plus d’une fois par semaine",
    "Pas du tout": "Pas du tout",
    "Plus de 3 fois/ jour": "Plus de 3 fois/ jour",
    "Plus d’une fois par semaine, Plus d’une fois ce mois-ci": "Plus d’une fois par semaine",
    "Plus de 3 fois/ jour, Plus d’une fois par semaine": "Plus de 3 fois/ jour",
    "NR": "NR",
    "Plus d’une fois ce mois-ci, Une fois ce mois-ci": "Plus d’une fois ce mois-ci",
}


dict_mort = {
    "nsp": "-1",
    "90+39+1": "130",
    "trop": "-1",
    "plus d'une centaine": "110",
    "nr": "-1",
    "une cinquantaine": "50",
    "je ne veux pas le savoir": "-1",
    "90 morts au bataclan, 1 au sdf, nsp pour les terrasses": "100",
    "14 bichat alibert ., 130 bataclan ., reste aucune idée": "150",
    "? mais trop, beaucoup trop": "-1",
    "-1 ., 1 mort est de trop !": "-1",
    "cinquantaine?": "50",
    "ne souhaite pas répondre (trop de souvenirs)": "-1",
    "+ d'une centaine": "110",
    "une centaine": "100",
    "une centaine je crois": "100",
    "une trentaine / soixantaine": "50",
    "beaucoup trop": "-1",
    "je ne veux pas le savoir.": "-1",
    "beaucoup": "-1",
    "des centaines": "200",
}

dico_n_att = {
    "nsp": "-1",
    "une dizaine": "10",
    """une dizaine (difficile de déterminer faut-il compter les aides "logistiques")""": "10",
    "une dizaine je crois": "10",
    "'plusieurs, je ne me souviens plus du nombre exact": "-1",
    "43987": "4",
    "une vingtaine directement ou indirectement": "20",
    "une quinzaine d'auteurs": "15",
    "nr": "-1",
    "?": "-1",
    "moins d'une dizaine": "8",
    "indetermine": "-1",
    "trois au bataclan, deux au stade de france + complices": "8",
    "ne souhaite pas répondre (trop de souvenirs)": "-1",
    "beaucoup": "-1",
    "43589": "4",
    "abdeslam est celui qui est toujours en vie": "-1",
    "c'est indeterminé. auteurs, complices, commanditaires": "-1",
    "daesh": "-1",
    "beaucoup trop!": "-1",
}


def encode_with_dict(x: str, dic: dict) -> int:
    """encode an alemtn based on on a dictionaries rules

    Args:
        x (str): _description_
        dic (dict): _description_

    Returns:
        int: _description_
    """
    for elt in dic.keys():
        if x == elt:
            return dic[elt]
    return -1


def encode_histoire(x: str) -> int:
    """normalize personal and family history

    Args:
        x (str): _description_

    Returns:
        int: _description_
    """
    if x == "Oui":
        return 1
    elif x == "Non":
        return 0
    else:
        return -1


def transform_evt(x: str) -> str:
    """deal with the unclear response

    Args:
        x (_type_): _description_

    Returns:
        _type_: _description_
    """
    if x == "Oui, Non":
        return "NR"
    else:
        return x


def transform_h_media(x: str, dic: dict) -> str:
    """noamrlize the number of hour pend in front of media

    Args:
        x (str): _description_
        dic (dict): _description_

    Returns:
        str: _description_
    """
    heure = x
    for elt in dic.keys():
        if x == elt:
            heure = dic[elt]
    if (heure == x) and (x != "NR"):
        number = re.findall(r"\d+", x)[0]
        heure = number

    if heure == "NR":
        return "NR"
    elif float(heure) == 0:
        return "aucune"
    elif float(heure) <= 1:
        return "moins d'1h"
    elif float(heure) <= 3:
        return "entre 1h et 3h"
    elif float(heure) <= 5:
        return "entre 3h et 5h"
    elif float(heure) <= 10:
        return "entre 5h et 10h"
    elif float(heure) <= 15:
        return "entre 10h et 15h"
    elif float(heure) > 15:
        return "plus de 15h"


def transform_h_media_num(x: str, dic: dict) -> int:
    """deal with unclear data in the number of hour

    Args:
        x (_type_): _description_
        dic (_type_): _description_

    Returns:
        _type_: _description_
    """
    heure = x
    for elt in dic.keys():
        if x == elt:
            heure = dic[elt]
    if (heure == x) and (x != "NR"):
        number = re.findall(r"\d+", x)[0]
        heure = number

    if heure == "NR":
        return -1
    elif float(heure) == 0:
        return 0
    elif float(heure) <= 1:
        return 1
    elif float(heure) >= 24:
        return 25
    else:
        return int(heure)


def transform_n_pers(x: str, dic: dict) -> int:
    """Encode the number of

    Args:
        x (str): _description_
        dic (dict): _description_

    Returns:
        int: _description_
    """
    fois = x
    for elt in dic.keys():
        if x.strip() == elt:
            fois = dic[elt]
            if fois == "NR":
                return float(-1)
            else:
                return min(float(fois), 200)
    try:
        number = re.findall(r"\d+", x)[0]
        fois = number
        if fois == "NR":
            return float(-1)
        elif float(fois) == 0:
            return 0
        else:
            return min(float(fois), 200)
    except:
        return -1


def transform_h_mois(x, dico):
    for elt in dico.keys():
        if x == elt:
            return dico[elt]


def transform_n_mort(x, dico):

    for elt in dico.keys():
        if x.strip().lower() == elt:
            return dico[elt]
    try:
        number = re.findall(r"\d+", x)[0]
        return number
    except:
        return x.strip().lower()


def encode_n_mort(x, dico):
    number = int(transform_n_mort(x, dico))
    if number <= 50:
        return "sous estimation forte"
    elif number <= 100:
        return "sous estimation faible"
    elif number <= 150:
        return "estimation correcte"
    elif number <= 200:
        return "sur estimation faible"
    elif number > 200:
        return "sur estimation forte"


def encode_est_n_mort(x, dico):
    number = int(transform_n_mort(x, dico))
    if 110 <= number <= 150:
        return "estimation correcte"
    else:
        return "estimation incorecte"


def transform_n_att(x, dico):

    if "dizaine" in x.strip().lower():
        return "10"

    elif "douzaine" in x.strip().lower():
        return "12"

    elif "quinzaine" in x.strip().lower():
        return "15"

    elif "vingtaine" in x.strip().lower():
        return "20"

    for elt in dico.keys():
        if x.strip().lower() == elt:
            return dico[elt]
    if "plusieur" in x.strip().lower():
        return "5"

    try:
        number = re.findall(r"\d+", x)[0]
        return number
    except:
        return x.strip().lower()


def est_c_att(n):

    if 6 <= n <= 10:
        return "estimation correct"
    else:
        return "estimation incorect"


def encode_souvenir(x):
    if x == "NR":
        return 0
    elif x == "Je ne m’en souviens pas":
        return 1
    elif x == "Je sais ou pense savoir":
        return 2
    elif x == "Je me souviens précisément":
        return 3
    else:
        return -1


def encode_mois(x):
    if x == "None":
        return -1
    elif x == "Pas du tout":
        return 0
    elif x == "Plus d’une fois ce mois-ci":
        return 1
    elif x == "Plus d’une fois par semaine":
        return 2
    elif x == "Plus de 3 fois/ jour":
        return 3
    else:
        return -1


def encode_norm_h(x):
    if x == "NR":
        return -1
    elif x == "aucune":
        return 0
    elif x == "entre 1h et 3h":
        return 1
    elif x == "entre 3h et 5h":
        return 2
    elif x == "entre 5h et 10h":
        return 3
    elif x == "entre 10h et 15h":
        return 4
    elif x == "plus de 15h":
        return 5
    else:
        return -1


def encode_norm_mort(x):
    if x == "sous estimation forte":
        return 0
    elif x == "sous estimation faible":
        return 1
    elif x == "estimation correcte":
        return 2
    elif x == "sur estimation faible":
        return 3
    elif x == "sur estimation forte":
        return 4
    else:
        return -1


def normalize_diplome_2(x):
    if x in ["Bac+5", "Bac+4", "Bac+8", "Bac+6", "Bac+7", "Bac+9"]:
        return "master or higher"
    elif x in ["Bac+2", "Bac+3", "Bac+1"]:
        return "bachelor"
    elif x == "Bac ou moins":
        return "high school or less"
    else:
        return "other"


def critere_A(x):
    if x == "C1 - SURVIVANT":
        return "A1"
    elif x == "C1 - TEMOIN":
        return "A2"
    elif x in ["C1 - FAMILLE/PROCHE", "C1 - ENDEUILLE"]:
        return "A3"
    elif x == "C1 - INTERVENANT PROFESSIONNEL":
        return "A4"
    else:
        return "A5"


def encode_situation_mattrimoniale(x):
    if x in ["EN COUPLE", "MARIE(E)/PACSE(E)"]:
        return 1
    else:
        return 0


def encode_mode_residence(x):
    if x in ["SEUL"]:
        return 1
    else:
        return 0


def transform_data(data):
    transformed_data = data.copy()

    # selection des colonnes
    transform_data = transformed_data[selected_col]

    transformed_data["nb_enfants_enc"] = transformed_data["nb_enfants"].apply(str)
    transformed_data["PTSD_complet_ou_incomplet"] = transformed_data.apply(
        lambda x: 1 if x["partial_PTSD_probable"] + x["PTSD_probable"] >= 1 else 0,
        axis=1,
    )
    # socio
    transformed_data["situation_matrimoniale_enc"] = transformed_data[
        "situation_matrimoniale"
    ].apply(encode_situation_mattrimoniale)
    transformed_data["mode_residence_enc"] = transformed_data["mode_residence"].apply(
        encode_mode_residence
    )

    # hours
    transformed_data["norm_h_13_14"] = transformed_data[
        "III_4_1_P1_III_4_1_ENTRE_LE_13_ET_LE_14_NOVEMBRE_AU_SOIR_COMBIEN_D_HEURES_PENSEZ_VOUS_AVOIR_LU_ECOUTE_OU_REGARDE_LE_DEROULEMENT_DES_EVENEMENTS_A_TRAVERS_LES_MEDIAS"
    ].apply(lambda x: transform_h_media(x, dict_h_13_14))
    transformed_data["num_h_13_14"] = transformed_data[
        "III_4_1_P1_III_4_1_ENTRE_LE_13_ET_LE_14_NOVEMBRE_AU_SOIR_COMBIEN_D_HEURES_PENSEZ_VOUS_AVOIR_LU_ECOUTE_OU_REGARDE_LE_DEROULEMENT_DES_EVENEMENTS_A_TRAVERS_LES_MEDIAS"
    ].apply(lambda x: transform_h_media_num(x, dict_h_13_14))
    transformed_data["num_h_mois"] = transformed_data[
        "III_5_1_P1_III_5_1_LE_MOIS_QUI_VIENT_DE_S_ECOULER_COMBIEN_DE_TEMPS_PENSEZ_VOUS_AVOIR_PASSE_A_LIRE_ECOUTER_OU_REGARDER_LE_DEROULEMENT_DES_EVENEMENTS_A_TRAVERS_LES_MEDIAS"
    ].apply(lambda x: transform_h_mois(x, dict_h_mois))

    # pers
    transformed_data["num_pers_13_14"] = transformed_data[
        "III_4_2_P1_III_4_2_ENTRE_LE_13_ET_LE_14_NOVEMBRE_AU_SOIR_COMBIEN_DE_FOIS_PENSEZ_VOUS_AVOIR_COMMUNIQUE_AVEC_QUELQU_UN_SUR_CES_EVENEMENTS_LORS_DE_CETTE_PERIODE"
    ].apply(lambda x: transform_n_pers(x, dict_pers_13_14))
    transformed_data["num_pers_mois"] = transformed_data[
        "III_5_2_P1_III_5_2_LE_MOIS_QUI_VIENT_DE_S_ECOULER_COMBIEN_DE_FOIS_PENSEZ_VOUS_AVOIR_COMMUNIQUE_AVEC_QUELQU_UN_SUR_CES_EVENEMENTS_LORS_DE_CETTE_PERIODE"
    ].apply(lambda x: transform_h_mois(x, dict_h_mois))

    # morts
    transformed_data["est_n_mort"] = transformed_data[
        "III_8_P1_III_8_QUEL_EST_LE_NOMBRE_DE_MORTS_CAUSES_PAR_CES_ATTENTATS_NOVEMBRE"
    ].apply(lambda x: encode_n_mort(x, dict_mort))
    transformed_data["n_mort"] = transformed_data[
        "III_8_P1_III_8_QUEL_EST_LE_NOMBRE_DE_MORTS_CAUSES_PAR_CES_ATTENTATS_NOVEMBRE"
    ].apply(lambda x: int(transform_n_mort(x, dict_mort)))
    transformed_data["est_c_mort"] = transformed_data[
        "III_8_P1_III_8_QUEL_EST_LE_NOMBRE_DE_MORTS_CAUSES_PAR_CES_ATTENTATS_NOVEMBRE"
    ].apply(lambda x: encode_est_n_mort(x, dict_mort))

    # attaquants

    transformed_data["n_att"] = transformed_data[
        "III_9_P1_III_9_QUEL_EST_LE_NOMBRE_D_AUTEURS_IMPLIQUES_DANS_CES_ATTENTATS_NOVEMBRE"
    ].apply(lambda x: min(int(transform_n_att(x, dico_n_att)), 50))
    transformed_data["est_c_att"] = transformed_data["n_att"].apply(
        lambda x: est_c_att(x)
    )

    transformed_data["souvenir_avant_nov"] = transformed_data[
        "III_3_1_P1_III_3_1_Precisez_souvenir_avant_novembre"
    ].apply(encode_souvenir)
    transformed_data["souvenir_apres_nov"] = transformed_data[
        "III_2_2_1_P1_III_2_2_1_Precisez_souvenir_fait_apres_novembre"
    ].apply(encode_souvenir)
    transformed_data["souvenir_heure_nov"] = transformed_data[
        "III_1_2_1_P1_III_1_2_1_Precisez_souvenir_heure_novembre"
    ].apply(encode_souvenir)
    transformed_data["souvenir_nov"] = transformed_data[
        "III_1_1_3_P1_III_1_1_2_Precisez_souvenir_novembre"
    ].apply(encode_souvenir)
    transformed_data["souvenir_tgv"] = transformed_data[
        "III_10_P1_III_10_VOUS_SOUVENEZ_VOUS_DE_L_ACCIDENT_DE_TGV_SURVENU_DEUX_JOURS_PLUS_TARD_EN_FRANCE"
    ].apply(encode_souvenir)
    transformed_data["souvenir_crash_avion"] = transformed_data[
        "III_18_P1_III_18_VOUS_SOUVENEZ_VOUS_DU_CRASH_D_AVION_GERMANWINGS_SURVENU_EN_MARS_2015"
    ].apply(encode_souvenir)
    transformed_data["num_h_mois_enc"] = transformed_data["num_h_mois"].apply(
        encode_mois
    )
    transformed_data["num_pers_mois_enc"] = transformed_data["num_pers_mois"].apply(
        encode_mois
    )
    transformed_data["norm_h_13_14_enc"] = transformed_data["norm_h_13_14"].apply(
        encode_norm_h
    )
    transformed_data["est_n_mort_enc"] = transformed_data["est_n_mort"].apply(
        encode_norm_mort
    )

    transformed_data["h_perso_enc"] = transformed_data[fac_h_perso[1]].apply(
        encode_histoire
    )
    transformed_data["h_famille_enc"] = transformed_data[fac_h_perso[0]].apply(
        encode_histoire
    )

    transformed_data["code_insee_enc"] = transformed_data["code_insee"].apply(
        lambda x: encode_with_dict(x, dict_code_insee)
    )
    transformed_data["diplome_num"] = transformed_data["diplome_enc"].apply(
        lambda x: encode_with_dict(x, dict_code_diplome)
    )

    transformed_data["sexe_enc"] = transformed_data["sexe"].apply(
        lambda x: 1 if x == "M" else 0
    )
    return transformed_data


def load_and_transform_data():
    table_ptsd, table = data_loading.load_data()
    co = data_loading.read_correspondance_table(utils.load_config_file()["local"])
    socio = data_loading.load_socio()
    socio_enc = utils_socio.transform_socio_data(socio)
    inference = compute_criterion.build_all_critetion_DSM5(
        table, ptsd_criterion.critere_dict
    )
    evt = data_loading.load_quest_evt()
    emo = data_loading.load_quest_emo()
    quest = evt.merge(emo, on="Identifiant")
    data = socio_enc.merge(quest, on="Identifiant")
    data = inference.merge(data, on="code")

    transformed_data = transform_data(data)

    transformed_data["diplome_enc_2"] = transformed_data["diplome_enc"].apply(
        normalize_diplome_2
    )
    transformed_data["critereA"] = transformed_data["cat_tem"].apply(critere_A)

    return transformed_data
