import os
import pandas as pd


from src.analysis import utils_statistics, utils_emotions


# facteur
fac_socio = [
    "age",
    "sexe",
    "nb_enfants",
    "code_insee",
    "diplome",
    "diplome_enc",
    "cat_tem",
    "cercle",
    "exposition",
    "situation_matrimoniale",
    "mode_residence",
]

fac_info = [
    "III_3_1_P1_III_3_1_Precisez_souvenir_avant_novembre",
    "III_2_2_1_P1_III_2_2_1_Precisez_souvenir_fait_apres_novembre",
    "III_1_2_1_P1_III_1_2_1_Precisez_souvenir_heure_novembre",
    "III_1_1_3_P1_III_1_1_2_Precisez_souvenir_novembre",
]

fac_h_perso = [
    "II_16_2_P1_II_16_2_EST_CE_QUE_LES_EVENEMENTS_DU_13_NOVEMBRE_VOUS_ONT_RAPPELE_D_AUTRES_EVENEMENTS_DE_VOTRE_FAMILLE",
    "II_16_1_P1_II_16_1_EST_CE_QUE_LES_EVENEMENTS_DU_13_NOVEMBRE_VOUS_ONT_RAPPELE_D_AUTRES_EVENEMENTS_DE_VOTRE_VIE_PERSONNELLE",
]

fac_media = [
    "III_4_1_P1_III_4_1_ENTRE_LE_13_ET_LE_14_NOVEMBRE_AU_SOIR_COMBIEN_D_HEURES_PENSEZ_VOUS_AVOIR_LU_ECOUTE_OU_REGARDE_LE_DEROULEMENT_DES_EVENEMENTS_A_TRAVERS_LES_MEDIAS",
    "III_4_2_P1_III_4_2_ENTRE_LE_13_ET_LE_14_NOVEMBRE_AU_SOIR_COMBIEN_DE_FOIS_PENSEZ_VOUS_AVOIR_COMMUNIQUE_AVEC_QUELQU_UN_SUR_CES_EVENEMENTS_LORS_DE_CETTE_PERIODE",
    "III_5_1_P1_III_5_1_LE_MOIS_QUI_VIENT_DE_S_ECOULER_COMBIEN_DE_TEMPS_PENSEZ_VOUS_AVOIR_PASSE_A_LIRE_ECOUTER_OU_REGARDER_LE_DEROULEMENT_DES_EVENEMENTS_A_TRAVERS_LES_MEDIAS",
    "III_5_2_P1_III_5_2_LE_MOIS_QUI_VIENT_DE_S_ECOULER_COMBIEN_DE_FOIS_PENSEZ_VOUS_AVOIR_COMMUNIQUE_AVEC_QUELQU_UN_SUR_CES_EVENEMENTS_LORS_DE_CETTE_PERIODE",
]

# impacts
imp_evt = [
    "III_8_P1_III_8_QUEL_EST_LE_NOMBRE_DE_MORTS_CAUSES_PAR_CES_ATTENTATS_NOVEMBRE",
    "III_9_P1_III_9_QUEL_EST_LE_NOMBRE_D_AUTEURS_IMPLIQUES_DANS_CES_ATTENTATS_NOVEMBRE",
]

imp_monde = [
    "III_10_P1_III_10_VOUS_SOUVENEZ_VOUS_DE_L_ACCIDENT_DE_TGV_SURVENU_DEUX_JOURS_PLUS_TARD_EN_FRANCE",
    "III_18_P1_III_18_VOUS_SOUVENEZ_VOUS_DU_CRASH_D_AVION_GERMANWINGS_SURVENU_EN_MARS_2015",
    # 'III_16_P1_III_16_QUEL_EST_LE_NOMBRE_DE_MORTS_CAUSES_PAR_LES_ATTENTATS_DE_JANVIER',
    "II_16_3_P1_II_16_3_EST_CE_QUE_LES_EVENEMENTS_DU_13_NOVEMBRE_VOUS_ONT_RAPPELE_D_AUTRES_EVENEMENTS_DE_L_HISTOIRE_AVEC_UN_GRAND_H",
]

emotion = [
    "II_5_1_P1_II_5_1_QUELLES_SONT_LES_EMOTIONS_QUE_VOUS_RESSENTEZ_QUAND_VOUS_PENSEZ_AUX_EVENEMENTS_DU_13_NOVEMBRE_AU_COURS_DU_MOIS_QUI_VIENT_DE_S_ECOULER",
    "II_5_2_P1_II_5_2_Propositions_emotions",
]

selected_col = (
    ["code"]
    + [
        "CB_probable",
        "CC_probable",
        "CD_probable",
        "CE_probable",
        "CG_probable",
        "PTSD_probable",
        "partial_PTSD_probable",
    ]
    + fac_socio
    + fac_media
    + fac_h_perso
    + fac_info
    + imp_evt
    + imp_monde
    + emotion
)


def compute_save_cercle_prevalance(
    data: pd.DataFrame,
    saving_folder="/home/robin/Code_repo/13_novembre_questionnaire_emmotionel/results/stats",
) -> pd.DataFrame:
    """

    Args:
        data (pd.DataFrame): _description_
        saving_folder (str, optional): _description_. Defaults to "/home/robin/Code_repo/13_novembre_questionnaire_emmotionel/results/stats".

    Returns:
        pd.DataFrame: _description_
    """
    df_result = pd.DataFrame(
        columns=[
            "categorie",
            "CB",
            "CC",
            "CD",
            "CE",
            "CG",
            "PTSD",
            "partital_PTSD",
            "PTSD_complet_ou_incomplet",
        ]
    )
    i = 0
    for cercle in [1, 2, 3, 4]:
        d = data[data["cercle"] == cercle]
        result = {}
        result["categorie"] = f"Cercle {cercle}"
        for col in ["CB", "CC", "CD", "CE", "CG", "PTSD", "partial_PTSD"]:
            result[col] = round(len(d[d[col + "_probable"] == 1]) / len(d) * 100, 2)
        result["PTSD_complet_ou_incomplet"] = round(
            len(d[d["PTSD_complet_ou_incomplet"] == 1]) / len(d) * 100, 2
        )
        df_result.loc[i] = pd.Series(result)
        i += 1

    for exp in [0, 1]:
        d = data[data["exposition"] == exp]
        result = {}
        result["categorie"] = f"Exposition {exp}"
        for col in ["CB", "CC", "CD", "CE", "CG", "PTSD", "partial_PTSD"]:
            result[col] = round(len(d[d[col + "_probable"] == 1]) / len(d) * 100, 2)
        result["PTSD_complet_ou_incomplet"] = round(
            len(d[d["PTSD_complet_ou_incomplet"] == 1]) / len(d) * 100, 2
        )
        df_result.loc[i] = pd.Series(result)
        i += 1

    for cat in data["cat_tem"].unique().tolist():
        d = data[data["cat_tem"] == cat]
        result = {}
        result["categorie"] = f"{cat}"
        for col in ["CB", "CC", "CD", "CE", "CG", "PTSD", "partial_PTSD"]:
            result[col] = round(len(d[d[col + "_probable"] == 1]) / len(d) * 100, 2)
        result["PTSD_complet_ou_incomplet"] = round(
            len(d[d["PTSD_complet_ou_incomplet"] == 1]) / len(d) * 100, 2
        )
        df_result.loc[i] = pd.Series(result)
        i += 1

    for cat in data["critereA"].unique().tolist():
        d = data[data["critereA"] == cat]
        result = {}
        result["categorie"] = f"{cat}"
        for col in ["CB", "CC", "CD", "CE", "CG", "PTSD", "partial_PTSD"]:
            result[col] = round(len(d[d[col + "_probable"] == 1]) / len(d) * 100, 2)
        result["PTSD_complet_ou_incomplet"] = round(
            len(d[d["PTSD_complet_ou_incomplet"] == 1]) / len(d) * 100, 2
        )
        df_result.loc[i] = pd.Series(result)
        i += 1

    df_result.to_csv(os.path.join(saving_folder, f"prevalance_ptsd_all_data.csv"))
    return df_result


def compute_save_socio_analysis(
    data: pd.DataFrame,
    cible: str,
    saving_folder="/home/robin/Code_repo/13_novembre_questionnaire_emmotionel/results/stats",
):
    """
    Compute the socio statistics analysis for target group

    Args:
        data (pd.DataFrame): data use for analysis
        cible (strt): name of the group columns
        saving_folder (str, optional): place to save the csv result. Defaults to "/home/robin/Code_repo/13_novembre_questionnaire_emmotionel/results/stats".

    Returns:
        np.array : list af results in data frame
    """
    socio_khi2 = utils_statistics.compute_khi_2_table(
        data=data,
        cible=[cible],
        col_list=[
            "sexe_enc",
            "code_insee_enc",
            "diplome_enc",
            "situation_matrimoniale",
        ],
        seuil=0.5,
    )

    socio_anova = utils_statistics.compute_anova_table(
        data=data, cible=[cible], col_list=["age"], seuil=0.1
    )
    # saving
    socio_khi2.to_csv(os.path.join(saving_folder, f"{cible}_socio_khi_2.csv"))
    socio_anova.to_csv(os.path.join(saving_folder, f"{cible}_socio_anova.csv"))

    return socio_khi2, socio_anova


def compute_save_PTSD_prev_analysis(
    data: pd.DataFrame,
    cible: str,
    saving_folder="/home/robin/Code_repo/13_novembre_questionnaire_emmotionel/results/stats",
) -> pd.DataFrame:
    """
    Compute the socio statistics analysis for target group

    Args:
        data (pd.DataFrame): data use for analysis
        cible (strt): name of the group columns
        saving_folder (str, optional): place to save the csv result. Defaults to "/home/robin/Code_repo/13_novembre_questionnaire_emmotionel/results/stats".

    Returns:
        ptsd_khi2 (pd.DataFrame) : list af results in data frame
    """
    ptsd_khi2 = utils_statistics.compute_khi_2_table(
        data=data,
        cible=[cible],
        col_list=[
            "PTSD_probable",
            "partial_PTSD_probable",
            "PTSD_complet_ou_incomplet",
        ],
        seuil=0.5,
    )

    # saving
    ptsd_khi2.to_csv(os.path.join(saving_folder, f"{cible}_PTSD_khi_2.csv"))

    return ptsd_khi2


def compute_save_PTSD_diagnosis(
    data: pd.DataFrame,
    group=None,
    saving_folder="/home/robin/Code_repo/13_novembre_questionnaire_emmotionel/results/stats",
) -> list:
    """compute ptsd statistic association

    Args:
        data (pd.DataFrame, group, optional): _description_. Defaults to None, saving_folder = "/home/robin/Code_repo/13_novembre_questionnaire_emmotionel/results/stats")->list(pd.DataFrame.

    Returns:
        _type_: _description_
    """
    if group == None:
        group_name = "all_population"
        selected_data = data
    elif group == "exposed":
        group_name = "exposed_population"
        selected_data = data[data["exposition"] == 1]
    elif group == "A1":
        group_name = "direct_exposition"
        selected_data = data[data["critereA"] == "A1"]

    ptsd_wilc = utils_statistics.compute_wilc_table(
        data=selected_data,
        cible=["PTSD_probable", "partial_PTSD_probable", "PTSD_complet_ou_incomplet"],
        col_list=["age"],
        seuil=1,
    )
    ptsd_khi2 = utils_statistics.compute_khi_2_table(
        data=selected_data,
        cible=["PTSD_probable", "partial_PTSD_probable", "PTSD_complet_ou_incomplet"],
        col_list=[
            "sexe_enc",
            "code_insee_enc",
            "diplome_enc",
            "situation_matrimoniale",
        ],
        seuil=1,
    )

    ptsd_khi2.to_csv(os.path.join(saving_folder, f"{group_name}_socio_PTSD_khi_2.csv"))
    ptsd_wilc.to_csv(os.path.join(saving_folder, f"{group_name}_socio_PTSD_wilc.csv"))

    return ptsd_wilc, ptsd_khi2


def compute_save_event_PTSD_diagnosis(
    data: pd.DataFrame,
    group=None,
    saving_folder="/home/robin/Code_repo/13_novembre_questionnaire_emmotionel/results/stats",
) -> list:
    """compute ptsd diagnosis association with event features :
        - 'norm_h_13_14','h_perso_enc', 'h_famille_enc','est_c_mort','est_c_att'
        - 'num_h_mois_enc','num_h_13_14', 'num_h_mois','num_pers_13_14', 'num_pers_mois',"n_mort", 'souvenir_avant_nov', 'souvenir_apres_nov',
       'souvenir_heure_nov','n_att', 'souvenir_nov','num_pers_mois_enc', 'norm_h_13_14_enc', 'est_n_mort_enc'
    Args:
        data (pd.DataFrame): _description_
        group (_type_, optional): _description_. Defaults to None.
        saving_folder (str, optional): _description_. Defaults to "/home/robin/Code_repo/13_novembre_questionnaire_emmotionel/results/stats".

    Returns:
        list: _description_
    """
    if group == None:
        group_name = "all_population"
        selected_data = data
    elif group == "exposed":
        group_name = "exposed_population"
        selected_data = data[data["exposition"] == 1]
    elif group == "A1":
        group_name = "direct_exposition"
        selected_data = data[data["critereA"] == "A1"]

    ptsd_wilc = utils_statistics.compute_wilc_table(
        data=selected_data,
        cible=["PTSD_probable", "partial_PTSD_probable", "PTSD_complet_ou_incomplet"],
        col_list=[
            "num_h_mois_enc",
            "num_h_13_14",
            "num_h_mois",
            "num_pers_13_14",
            "num_pers_mois",
            "n_mort",
            "souvenir_avant_nov",
            "souvenir_apres_nov",
            "souvenir_heure_nov",
            "n_att",
            "souvenir_nov",
            "num_pers_mois_enc",
            "norm_h_13_14_enc",
            "est_n_mort_enc",
        ],
        seuil=1,
    )
    ptsd_khi2 = utils_statistics.compute_khi_2_table(
        data=selected_data,
        cible=["PTSD_probable", "partial_PTSD_probable", "PTSD_complet_ou_incomplet"],
        col_list=[
            "norm_h_13_14",
            "h_perso_enc",
            "h_famille_enc",
            "est_c_mort",
            "est_c_att",
        ],
        seuil=1,
    )

    ptsd_khi2.to_csv(
        os.path.join(saving_folder, f"{group_name}_media_memory_history_PTSD_khi_2.csv")
    )
    ptsd_wilc.to_csv(
        os.path.join(saving_folder, f"{group_name}_media_memory_history_PTSD_wilc.csv")
    )

    return ptsd_wilc, ptsd_khi2


def compute_save_PTSD_emotion(
    data: pd.DataFrame,
    group=None,
    saving_folder="/home/robin/Code_repo/13_novembre_questionnaire_emmotionel/results/stats",
) -> pd.DataFrame:
    if group == None:
        group_name = "all_population"
        selected_data = data
    elif group == "exposed":
        group_name = "exposed_population"
        selected_data = data[data["exposition"] == 1]
    elif group == "A1":
        group_name = "direct_exposition"
        selected_data = data[data["critereA"] == "A1"]

    ptsd_khi2 = utils_statistics.compute_khi_2_table(
        data=selected_data,
        cible=["PTSD_probable", "partial_PTSD_probable", "PTSD_complet_ou_incomplet"],
        col_list=[elt.strip().lower() for elt in utils_emotions.em_list],
        seuil=1,
    )

    ptsd_khi2.to_csv(
        os.path.join(saving_folder, f"{group_name}_emotion_PTSD_khi_2.csv")
    )

    return ptsd_khi2


def compute_save_emotion_socio_analysis(
    data: pd.DataFrame,
    saving_folder="/home/robin/Code_repo/13_novembre_questionnaire_emmotionel/results/stats",
):
    """
    Compute the socio statistics analysis for target group

    Args:
        data (pd.DataFrame): data use for analysis
        cible (strt): name of the group columns
        saving_folder (str, optional): place to save the csv result. Defaults to "/home/robin/Code_repo/13_novembre_questionnaire_emmotionel/results/stats".

    Returns:
        np.array : list af results in data frame
    """
    socio_khi2 = utils_statistics.compute_khi_2_table(
        data=data,
        cible=["sexe_enc", "cercle", "critereA"],
        col_list=[elt.strip().lower() for elt in utils_emotions.em_list],
        seuil=1,
    )

    socio_anova = utils_statistics.compute_anova_table(
        data=data,
        cible=[elt.strip().lower() for elt in utils_emotions.em_list],
        col_list=["age"],
        seuil=1,
    )
    # saving
    socio_khi2.to_csv(os.path.join(saving_folder, f"emotion_socio_khi_2.csv"))
    socio_anova.to_csv(os.path.join(saving_folder, f"emotion_socio_anova.csv"))

    return socio_khi2, socio_anova


def compute_save_emotion_media(
    data: pd.DataFrame,
    group=None,
    saving_folder="/home/robin/Code_repo/13_novembre_questionnaire_emmotionel/results/stats",
):
    if group == None:
        group_name = "all_population"
        selected_data = data
    elif group == "exposed":
        group_name = "exposed_population"
        selected_data = data[data["exposition"] == 1]
    elif group == "A1":
        group_name = "direct_exposition"
        selected_data = data[data["critereA"] == "A1"]

    emo_khi2 = utils_statistics.compute_khi_2_table(
        data=selected_data,
        cible=["norm_h_13_14", "h_perso_enc", "num_h_mois_enc"],
        col_list=[elt.strip().lower() for elt in utils_emotions.em_list],
        seuil=1,
    )

    emo_khi2.to_csv(
        os.path.join(
            saving_folder, f"{group_name}_media_memory_history_emotion_khi2.csv"
        )
    )

    return emo_khi2


def compute_save_PTSD_memory(
    data: pd.DataFrame,
    group=None,
    saving_folder="/home/robin/Code_repo/13_novembre_questionnaire_emmotionel/results/stats",
):
    if group == None:
        group_name = "all_population"
        selected_data = data
    elif group == "exposed":
        group_name = "exposed_population"
        selected_data = data[data["exposition"] == 1]
    elif group == "A1":
        group_name = "direct_exposition"
        selected_data = data[data["critereA"] == "A1"]

    emo_wilc = utils_statistics.compute_wilc_table(
        data=selected_data,
        cible=["PTSD_probable", "partial_PTSD_probable", "PTSD_complet_ou_incomplet"],
        col_list=[
            "souvenir_avant_nov",
            "souvenir_apres_nov",
            "souvenir_heure_nov",
            "souvenir_nov",
            "souvenir_crash_avion",
            "souvenir_tgv",
        ],
        seuil=1,
    )

    emo_wilc.to_csv(os.path.join(saving_folder, f"{group_name}_memory_PTSD_wilc.csv"))

    return emo_wilc


def compute_save_PTSD_emotional_response(
    data: pd.DataFrame,
    group=None,
    saving_folder="/home/robin/Code_repo/13_novembre_questionnaire_emmotionel/results/stats",
):
    if group == None:
        group_name = "all_population"
        selected_data = data
    elif group == "exposed":
        group_name = "exposed_population"
        selected_data = data[data["exposition"] == 1]
    elif group == "non_exposed":
        group_name = "exposed_population"
        selected_data = data[data["exposition"] == 0]
    elif group == "A1":
        group_name = "direct_exposition"
        selected_data = data[data["critereA"] == "A1"]

    rank_sum = utils_emotions.compute_rank_sum_table_emotion(
        selected_data,
        ["PTSD_probable", "partial_PTSD_probable", "PTSD_complet_ou_incomplet"],
        seuil=1,
    )

    rank_sum.to_csv(os.path.join(saving_folder, f"{group_name}_emotion_PTSD_khi_2.csv"))

    return rank_sum


def compute_save_PTSD_emotion_association(
    data: pd.DataFrame,
    association_names: list,
    group=None,
    saving_folder="/home/robin/Code_repo/13_novembre_questionnaire_emmotionel/results/stats",
):
    if group == None:
        group_name = "all_population"
        selected_data = data
    elif group == "exposed":
        group_name = "exposed_population"
        selected_data = data[data["exposition"] == 1]
    elif group == "A1":
        group_name = "direct_exposition"
        selected_data = data[data["critereA"] == "A1"]
    elif group == "A3":
        group_name = "deuil_exposition"
        selected_data = data[data["critereA"] == "A3"]
    elif group == "A4":
        group_name = "professional_exposition"
        selected_data = data[data["critereA"] == "A4"]
    elif group == "not_pro":
        group_name = "not_professional_exposition"
        selected_data = data[data["critereA"] != "A4"]

    ptsd_khi2 = utils_statistics.compute_khi_2_table(
        data=selected_data,
        cible=["PTSD_probable", "partial_PTSD_probable", "PTSD_complet_ou_incomplet"],
        col_list=association_names,
        seuil=0.01,
    )

    ptsd_khi2.to_csv(
        os.path.join(saving_folder, f"{group_name}_associaion_emotion_PTSD_khi_2.csv")
    )

    return ptsd_khi2
